==> vue3-components-0.1.6.tgz: package/es/form/src/form.js <==
import { defineComponent as B, computed as I, ref as C, shallowRef as T, onMounted as L, watch as N, createVNode as n, resolveComponent as w, mergeProps as m, toRef as q, unref as z, Fragment as G, nextTick as _, isVNode as H } from "vue";
import { formProps as J, formEmits as Q } from "./props.js";
import { dialogProps as W, dialogEmits as X, ElFormItem as O, ElCol as D } from "element-plus";
import { pickObjByKeys as v, firstUppercase as Y, deepClone as Z, omitObjByKeys as ee } from "@tomiaa/utils";
import { KCustomElement as g } from "../../customElement/index.js";
import { Toolbar as oe, Editor as le } from "@wangeditor/editor-for-vue";
import "../../node_modules/.pnpm/@wangeditor_editor@5.1.18/node_modules/@wangeditor/editor/dist/css/style.js";
function te(o) {
  return typeof o == "function" || Object.prototype.toString.call(o) === "[object Object]" && !H(o);
}
const fe = B({
  name: "KForm",
  props: J,
  emits: Q,
  setup(o, {
    attrs: u,
    slots: f,
    emit: s,
    expose: K
  }) {
    const b = o.modelValue !== void 0, F = ["", !1].includes(u.inline), S = I(() => v(o, Object.keys(W))), j = {};
    for (const e in X)
      j["on" + Y(e)] = () => s(e);
    const d = C(), U = () => {
      var e;
      return n(w("el-dialog"), m({
        ref: d
      }, j, {
        "onUpdate:modelValue": (l) => s("update:modelValue", l),
        onClosed: o.destroyOnClose && ((e = i.value) == null ? void 0 : e.resetFields)
      }, S.value), {
        footer: o.showActions ? k : void 0,
        ...f,
        default: R
      });
    }, k = () => {
      var l, a, r, M;
      let e = [{
        el: "el-button",
        type: "primary",
        "v-if": o.actionsConfig.showSubmit,
        onClick() {
          var A, P;
          const c = {
            formRef: i,
            dialogRef: d,
            formModel: t,
            validate: (A = i.value) == null ? void 0 : A.validate,
            rawFormModel: h()
          };
          if (o.autoValidateOnSubmit) {
            (P = i.value) == null || P.validate(($) => {
              s($ ? "submit" : "submitCheckFail", c);
            });
            return;
          }
          s("submit", c);
        },
        children: (l = o.actionsConfig.submitText) != null ? l : "\u63D0\u4EA4"
      }, {
        el: "el-button",
        "v-if": o.actionsConfig.showReset,
        onClick() {
          var c;
          i.value.resetFields(), s("reset", {
            formRef: i,
            dialogRef: d,
            formModel: t,
            validate: (c = i.value) == null ? void 0 : c.validate,
            rawFormModel: h()
          });
        },
        children: (a = o.actionsConfig.resetText) != null ? a : "\u91CD\u7F6E"
      }, {
        el: "el-button",
        "v-if": o.actionsConfig.showCancel,
        onClick() {
          s("update:modelValue", !1), s("cancel");
        },
        children: (r = o.actionsConfig.cancelText) != null ? r : "\u53D6\u6D88"
      }];
      return (M = o.actionsConfig) != null && M.custom && (e = o.actionsConfig.custom(e)), b ? n(g, {
        list: e
      }, null) : F ? n(O, null, {
        default: () => [n(g, {
          list: e
        }, null)]
      }) : n(D, o.actionsConfig, {
        default: () => [n(O, null, {
          default: () => [n(g, {
            list: e
          }, null)]
        })]
      });
    }, i = C(), t = C(u.model || {}), V = () => {
      o.options.forEach((e) => {
        if (e.prop && typeof e.prop == "string") {
          const l = e.el === "el-upload" ? "fileList" : "modelValue";
          t.value[e.prop] = q(e, l);
        }
      });
    };
    V();
    const h = () => {
      const e = {};
      for (const l in t.value)
        e[l] = z(t.value[l]);
      return e;
    }, R = () => n(w("el-form"), m(u, {
      ref: i,
      model: t.value
    }), {
      default: () => [n(w("el-row"), u, {
        default: () => [o.options.map((e) => {
          const l = e.el === "el-upload" ? "fileList" : "modelValue";
          let a = {
            ...v(e, Object.keys(D.props)),
            class: e.class ? `${e.class}__el-col` : "",
            el: "el-col",
            children: {
              ...v(e, Object.keys(O.props)),
              class: e.class ? `${e.class}__el-form-item` : "",
              el: "el-form-item",
              children: {
                ...e,
                [l]: t.value[e.prop],
                [`onUpdate:${l}`](r) {
                  Object.prototype.hasOwnProperty.call(t.value, e.prop) && (t.value[e.prop] = r);
                }
              }
            }
          };
          return F && (a = a.children), e.el === "editor" && (a.children.children = x(e)), n(g, {
            list: a
          }, te(f) ? f : {
            default: () => [f]
          });
        }), o.showActions && !b && k()]
      })]
    }), p = T({}), x = (e) => (e.prop && !p.value[e.prop] && (p.value[e.prop] = T()), n(G, null, [n(oe, m({
      style: "border-bottom: 1px solid #ccc",
      mode: "default",
      editor: e.prop && p.value[e.prop].value
    }, e.editorAttrs), null), n(le, m({
      style: "height: 300px; width: 100%; overflow-y: hidden",
      mode: "default",
      modelValue: t.value[e.prop],
      "onUpdate:model-value": (l) => {
        Object.prototype.hasOwnProperty.call(t.value, e.prop) && (t.value[e.prop] = l);
      },
      onOnCreated: (l) => {
        e.prop && (p.value[e.prop].value = l);
      }
    }, e.toolbarAttrs), null)])), y = {
      initFormModel: V,
      getRawFormModel: h,
      setFormModel: async (e, {
        includes: l = [...o.options.map((r) => r.prop).filter((r) => r), "id"],
        exclude: a = []
      } = {}) => {
        e = Z(e);
        let r = l != null && l.length ? v(e, l) : e;
        a != null && a.length && (r = ee(r, a)), await _(), Object.assign(t.value, r);
      },
      getFormRef: () => i,
      getDialogRef: () => d,
      formModel: t
    }, E = async () => {
      await _(), Object.assign(y, i.value), Object.assign(y, d.value);
    };
    return L(E), N(() => o.modelValue, E), K(y), () => n("div", null, [b ? U() : R()]);
  }
});
export {
  fe as default
};

==> vue3-components-0.1.7.tgz: package/es/form/src/form.js <==
import { defineComponent as B, computed as I, ref as w, shallowRef as T, onMounted as L, watch as N, createVNode as n, resolveComponent as O, mergeProps as m, toRef as q, unref as z, Fragment as G, nextTick as _, isVNode as H } from "vue";
import { formProps as J, formEmits as Q } from "./props.js";
import { dialogProps as W, dialogEmits as X, ElFormItem as F, ElCol as D } from "element-plus";
import { pickObjByKeys as v, firstUppercase as Y, deepClone as Z, omitObjByKeys as ee } from "@tomiaa/utils";
import { KCustomElement as g } from "../../customElement/index.js";
import { Toolbar as oe, Editor as le } from "@wangeditor/editor-for-vue";
import "../../node_modules/.pnpm/@wangeditor_editor@5.1.18/node_modules/@wangeditor/editor/dist/css/style.js";
function te(o) {
  return typeof o == "function" || Object.prototype.toString.call(o) === "[object Object]" && !H(o);
}
const fe = B({
  name: "KForm",
  props: J,
  emits: Q,
  setup(o, {
    attrs: d,
    slots: f,
    emit: s,
    expose: K
  }) {
    const b = o.modelValue !== void 0, j = ["", !1].includes(d.inline), S = I(() => v(o, Object.keys(W))), k = {};
    for (const e in X)
      k["on" + Y(e)] = () => s(e);
    const u = w(), U = () => n(O("el-dialog"), m({
      ref: u
    }, k, {
      "onUpdate:modelValue": (e) => s("update:modelValue", e),
      onClosed: () => {
        var e;
        !o.destroyOnClose || (h(), (e = i.value) == null || e.resetFields());
      }
    }, S.value), {
      footer: o.showActions ? V : void 0,
      ...f,
      default: R
    }), V = () => {
      var l, a, r, M;
      let e = [{
        el: "el-button",
        type: "primary",
        "v-if": o.actionsConfig.showSubmit,
        onClick() {
          var A, P;
          const c = {
            formRef: i,
            dialogRef: u,
            formModel: t,
            validate: (A = i.value) == null ? void 0 : A.validate,
            rawFormModel: y()
          };
          if (o.autoValidateOnSubmit) {
            (P = i.value) == null || P.validate(($) => {
              s($ ? "submit" : "submitCheckFail", c);
            });
            return;
          }
          s("submit", c);
        },
        children: (l = o.actionsConfig.submitText) != null ? l : "\u63D0\u4EA4"
      }, {
        el: "el-button",
        "v-if": o.actionsConfig.showReset,
        onClick() {
          var c;
          i.value.resetFields(), s("reset", {
            formRef: i,
            dialogRef: u,
            formModel: t,
            validate: (c = i.value) == null ? void 0 : c.validate,
            rawFormModel: y()
          });
        },
        children: (a = o.actionsConfig.resetText) != null ? a : "\u91CD\u7F6E"
      }, {
        el: "el-button",
        "v-if": o.actionsConfig.showCancel,
        onClick() {
          s("update:modelValue", !1), s("cancel");
        },
        children: (r = o.actionsConfig.cancelText) != null ? r : "\u53D6\u6D88"
      }];
      return (M = o.actionsConfig) != null && M.custom && (e = o.actionsConfig.custom(e)), b ? n(g, {
        list: e
      }, null) : j ? n(F, null, {
        default: () => [n(g, {
          list: e
        }, null)]
      }) : n(D, o.actionsConfig, {
        default: () => [n(F, null, {
          default: () => [n(g, {
            list: e
          }, null)]
        })]
      });
    }, i = w(), t = w(d.model || {}), h = () => {
      t.value = {}, o.options.forEach((e) => {
        if (e.prop && typeof e.prop == "string") {
          const l = e.el === "el-upload" ? "fileList" : "modelValue";
          t.value[e.prop] = q(e, l);
        }
      });
    };
    h();
    const y = () => {
      const e = {};
      for (const l in t.value)
        e[l] = z(t.value[l]);
      return e;
    }, R = () => n(O("el-form"), m(d, {
      ref: i,
      model: t.value
    }), {
      default: () => [n(O("el-row"), d, {
        default: () => [o.options.map((e) => {
          const l = e.el === "el-upload" ? "fileList" : "modelValue";
          let a = {
            ...v(e, Object.keys(D.props)),
            class: e.class ? `${e.class}__el-col` : "",
            el: "el-col",
            children: {
              ...v(e, Object.keys(F.props)),
              class: e.class ? `${e.class}__el-form-item` : "",
              el: "el-form-item",
              children: {
                ...e,
                [l]: t.value[e.prop],
                [`onUpdate:${l}`](r) {
                  Object.prototype.hasOwnProperty.call(t.value, e.prop) && (t.value[e.prop] = r);
                }
              }
            }
          };
          return j && (a = a.children), e.el === "editor" && (a.children.children = x(e)), n(g, {
            list: a
          }, te(f) ? f : {
            default: () => [f]
          });
        }), o.showActions && !b && V()]
      })]
    }), p = T({}), x = (e) => (e.prop && !p.value[e.prop] && (p.value[e.prop] = T()), n(G, null, [n(oe, m({
      style: "border-bottom: 1px solid #ccc",
      mode: "default",
      editor: e.prop && p.value[e.prop].value
    }, e.editorAttrs), null), n(le, m({
      style: "height: 300px; width: 100%; overflow-y: hidden",
      mode: "default",
      modelValue: t.value[e.prop],
      "onUpdate:model-value": (l) => {
        Object.prototype.hasOwnProperty.call(t.value, e.prop) && (t.value[e.prop] = l);
      },
      onOnCreated: (l) => {
        e.prop && (p.value[e.prop].value = l);
      }
    }, e.toolbarAttrs), null)])), C = {
      initFormModel: h,
      getRawFormModel: y,
      setFormModel: async (e, {
        includes: l = [...o.options.map((r) => r.prop).filter((r) => r), "id"],
        exclude: a = []
      } = {}) => {
        e = Z(e);
        let r = l != null && l.length ? v(e, l) : e;
        a != null && a.length && (r = ee(r, a)), await _(), Object.assign(t.value, r);
      },
      getFormRef: () => i,
      getDialogRef: () => u,
      formModel: t
    }, E = async () => {
      await _(), Object.assign(C, i.value), Object.assign(C, u.value);
    };
    return L(E), N(() => o.modelValue, E), K(C), () => n("div", null, [b ? U() : R()]);
  }
});
export {
  fe as default
};
